package de.jottyfan.camporganizer.module.admin;

import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;

import de.jottyfan.camporganizer.module.camplist.CommonController;
import de.jottyfan.camporganizer.module.mail.MailBean;

/**
 *
 * @author jotty
 *
 */
@Controller
public class AdminController extends CommonController {

	private static final Logger LOGGER = LogManager.getLogger(AdminController.class);

	@Autowired
	private AdminService service;

	@Value("${spring.mail.username}")
	private String from;

	@GetMapping("/admin")
	public String getMain(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		return "/admin/main";
	}

	@GetMapping("/admin/main")
	public String getMainDirectly() {
		return "redirect:/admin/main";
	}

	@GetMapping("/admin/mail")
	public String getMail(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		MailBean mailBean = new MailBean();
		mailBean.setFrom(from);
		mailBean.getTo().add(getCurrentEmail(request));
		model.addAttribute("bean", mailBean);
		return "/admin/mail";
	}

	@PostMapping("/admin/mail/send")
	public String sendMail(@Valid @ModelAttribute("bean") MailBean bean, final BindingResult bindingResult, Model model,
			HttpServletRequest request) {
		super.setupSession(model, request);
		if (bindingResult.hasErrors()) {
			for (ObjectError error : bindingResult.getAllErrors())
				LOGGER.error("error {}: {}", error.getCode(), error.getDefaultMessage());
			return "/admin/mail";
		}
		service.sendMail(bean);
		return "redirect:/admin";
	}

	@GetMapping("/admin/document")
	public String getDocuments(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("documents", service.getAllDocuments());
		return "/admin/document";
	}

	@GetMapping("/admin/document/add")
	public String prepareAddDocument(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("bean", new DocumentBean());
		return "/admin/document_edit";
	}

	@GetMapping("/admin/document/edit/{id}")
	public String prepareAddDocument(@PathVariable Integer id, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("bean", service.getDocument(id));
		return "/admin/document_edit";
	}

	@PostMapping("/admin/document/update")
	public String updateDocument(@Valid @ModelAttribute("bean") DocumentBean bean,
			final BindingResult bindingResult, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		if (bindingResult.hasErrors()) {
			for (ObjectError error : bindingResult.getAllErrors())
				LOGGER.error("error {}: {}", error.getCode(), error.getDefaultMessage());
			return "/admin/document_edit";
		}
		service.updateDocument(bean);
		return "redirect:/admin/document";
	}

	@GetMapping("/admin/document/delete/{id}")
	public String deleteDocument(@PathVariable Integer id, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		service.deleteDocument(id);
		return "redirect:/admin/document";
	}

	@GetMapping("/admin/location")
	public String getLocations(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("locations", service.getLocations());
		return "/admin/location";
	}

	@GetMapping("/admin/location/add")
	public String prepareAddLocation(Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("bean", new LocationBean());
		model.addAttribute("documents", service.getLocationDocuments());
		return "/admin/location_edit";
	}

	@GetMapping("/admin/location/edit/{id}")
	public String prepareAddLocation(@PathVariable Integer id, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		model.addAttribute("bean", service.getLocation(id));
		model.addAttribute("documents", service.getLocationDocuments());
		return "/admin/location_edit";
	}

	@PostMapping("/admin/location/update")
	public String updateDocument(@Valid @ModelAttribute("bean") LocationBean bean,
			final BindingResult bindingResult, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		if (bindingResult.hasErrors()) {
			for (ObjectError error : bindingResult.getAllErrors())
				LOGGER.error("error {}: {}", error.getCode(), error.getDefaultMessage());
			return "/admin/location_edit";
		}
		service.upsertLocation(bean);
		return "redirect:/admin/location";
	}

	@GetMapping("/admin/location/delete/{id}")
	public String deleteLocation(@PathVariable Integer id, Model model, HttpServletRequest request) {
		super.setupSession(model, request);
		service.deleteLocation(id);
		return "redirect:/admin/location";
	}
}
